@@ -138,11 +138,11 @@ glade_clipboard_view_cell_function (GtkTreeViewColumn *tree_column,
 	g_return_if_fail (GLADE_IS_WIDGET (widget));
 	g_return_if_fail (widget->name != NULL);
 	g_return_if_fail (widget->widget_class != NULL);
-	g_return_if_fail (widget->widget_class->icon != NULL);
+	g_return_if_fail (widget->widget_class->small_icon != NULL);
 
 	if (is_icon)
 		g_object_set (G_OBJECT (cell),
-			      "pixbuf", widget->widget_class->icon,
+			      "pixbuf", widget->widget_class->small_icon,
 			      NULL);
 	else
 		g_object_set (G_OBJECT (cell),
@@ -207,6 +207,8 @@ glade_clipboard_view_create_tree_view (GladeClipboardView *view)
 						 GINT_TO_POINTER (1), NULL);
 
 	renderer = gtk_cell_renderer_text_new ();
+	g_object_set (G_OBJECT (renderer), 
+		      "xpad", 6, NULL);
 	gtk_tree_view_column_pack_start (column, renderer, TRUE);
 	gtk_tree_view_column_set_cell_data_func (column, renderer,
 						 glade_clipboard_view_cell_function,
